Is this for me?
===============

CAPPr is for you if you:

#. Want to do text classification, i.e., you want an LLM to pick from a list of choices

#. Can locally load HuggingFace models, or pay to use OpenAI models.
